Struct ListenerLocalBuilder

pub struct ListenerLocalBuilder<'a> { /* private fields */ }
A builder for registering core event callbacks.

Use Core::add_listener_local to create this and register callbacks that will be called when events of interest occur. After adding callbacks, use register to get back a core::Listener.

Examples

let core_listener = core.add_listener_local()
    .info(|info| println!("New core info: {info:?}"))
    .done(|id, seq| println!("Object {id} received done with seq {seq:?}"))
    .error(|id, seq, res, message| {
        println!("Object {id} received error with seq {seq:?}, error code {res} and message {message}")
    })
    .register();

Implementations

Source

impl<'a> ListenerLocalBuilder<'a>

pub fn info<F>(self, info: F) -> Self
where F: Fn(&Info) + 'static,

Set the core info event callback of the listener.

This event is emitted when first bound to the core or when the hello method is called.

Callback parameters

info: New core info

Examples
let core_listener = core.add_listener_local()
    .info(|info| println!("New core info: {info:?}"))
    .register();
pub fn done<F>(self, done: F) -> Self
where F: Fn(u32, AsyncSeq) + 'static,

Set the core done event callback of the listener.

This event is emitted as a result of a sync call with the same seq number.

Callback parameters

id: Object where the done event occurred
seq: The seq number passed to the sync call that emitted this.

Examples
let core_listener = core.add_listener_local()
    .done(|id, seq| println!("Object {id} received done with seq {seq:?}"))
    .register();
pub fn error<F>(self, error: F) -> Self
where F: Fn(u32, i32, i32, &str) + 'static,

Set the core error event callback of the listener.

This event is emitted when a fatal (non-recoverable) error has occurred. The id argument is the proxy object where the error occurred, most often in response to a request to that object. The message is a brief description of the error, for (debugging) convenience.

This event is usually also emitted on the proxy object with id id.

Callback parameters

id: Object where the error occurred
seq: Sequence number that generated the error
res: Error code
message: Error description

Examples
let core_listener = core.add_listener_local()
    .error(|id, seq, res, message| {
        println!("Object {id} received error with seq {seq:?}, error code {res} and message {message}")
    })
    .register();
pub fn register(self) -> Listener

Subscribe to events and register any provided callbacks.